#!/bin/sh
# Auteur : Michel Petit <pemichel@wanadoo.fr>
# Licence : GPL version 2.0 ou superieure
# Script resumant la configuration de la machine sur laquelle il tourne dans un
# document PHP.
# Version : 20051122
################################################################################
# BUG
# ===
# - Bug dans les systemes de fichier present à la derniere colonne
# - Cadre de la partie PCI non ferme
################################################################################
# TODO
# ====
# - Mettre une section sur les shells disponibles ?
# - Lister les repertoires du path
#################################################################################

REF_SCRIPT='yes'
SCRIPT_VERSION='20051122'
SCRIPT_NOM=$(basename "$0")
ROOT_UID=0
KERNEL=$(uname -r | sed 's/^2\.\(.\).*$/\1/g')
MACHINE=$(hostname)
PERSONNE=$(logname)
DATEFICHIER=$(date +'%F' | tr -d "\n")

# Voici les diverses fonctions utilisees :
# fs_configures()		Affiche les systemes de fichiers configures (fstab)
# fs_presents()			Affiche les systemes de fichiers presents (fdisk)
# info_X()			Information de X Window
# conf_X()			Configuration de X Window
# langages_interpretes()	Affiche quelques infos sur les langages de programmations interpretes presents
# memoire()			Information sur la memoire (swap, ram...)
# modules_charges()		Affiche les modules charges
# modules_disponibles()		Affiche et decrit les modules disponibles
# pci()				Information sur les devices PCI
# processeur()			Informations sur le processeur
# systeme_exploitation()		Information sur le systeme d'exploitation
# taille_partitions()		Information sur la taille des partitions
# version_programmes_cles()	Information de certains programmes importants
# bootmanager()			Affiche la configuration du bootmanager

processeur(){
echo "<section id=\"I\" noNumber=\"1\">
<title>Processeur</title>"

echo "<tableau width=\"80%\" border=\"1\">
	 <entete>
		<colonne>Propriete</colonne>
		<colonne>Valeur</colonne>
	</entete>"

echo "<ligne>"
cat /proc/cpuinfo | awk '/^vendor_id/ {print "<colonne>Id</colonne><colonne>" $3 "</colonne>"}' | tr -d "\n"
echo "</ligne>"
echo "<ligne>"
cat /proc/cpuinfo | awk '/^cpu MHz/ {print "<colonne>Frequence (MHz)</colonne><colonne>" $4 "</colonne>"}' | tr -d "\n"
echo "</ligne>"
echo "<ligne>"
cat /proc/cpuinfo | awk '/^bogomips/ {print "<colonne>Bogomips</colonne><colonne>" $3 "</colonne>"}' | tr -d "\n"
echo "</ligne>"
echo "<ligne>"
echo -ne '<colonne>Modele</colonne><colonne>'
cat /proc/cpuinfo | grep "model name" | sed 's/^model name[\t]*:* *//g' | tr -d "\n"
echo "</colonne></ligne>"
echo "<ligne>"
echo -ne '<colonne>Flags</colonne><colonne>'
cat /proc/cpuinfo | grep "flags" | sed 's/^flags[\t]*:* *//g' | tr -d "\n"
echo "</colonne></ligne>"
echo "</tableau>"
echo "</section>"
}

systeme_exploitation(){
echo "<section id=\"II\" noNumber=\"1\"><title>Systeme d'expoitation</title>
<liste>
<element>Architecture&#160;: $(uname -m)</element>
<element>Nom&#160;: $(uname -n)</element>
<element>Systeme&#160;: $(uname -s) version $(uname -r)</element>
<element>Date de compilation&#160;: $(uname -v)</element>
</liste>
</section>"
}

fs_configures(){
echo "<section id=\"III\" noNumber=\"1\"><title>Systemes de fichiers configures</title>
<tableau width=\"80%\" border=\"1\">
<entete><colonne>Systeme de fichier</colonne><colonne>Point de montage</colonne><colonne>Type</colonne><colonne>Options</colonne><colonne>dump</colonne><colonne>Pass</colonne></entete>"

cat /etc/fstab | grep [0-2] | sed 's/#.*$//g; /^[[:space:]]*$/d' | awk '{print "<ligne><colonne>" $1 "</colonne><colonne>" $2 "</colonne><colonne>" $3 "</colonne><colonne>" $4 "</colonne><colonne>" $5 "</colonne><colonne>" $6 "</colonne></ligne>"}'

echo "</tableau>"
echo "</section>"
}

fs_presents(){
echo "<section id=\"IV\" noNumber=\"1\"><title>Systemes de fichiers presents</title>"

if [ -f $(which fdisk) ]
then
echo "<tableau width=\"80%\" border=\"1\">
<entete><colonne>Peripherique</colonne><colonne>Debut</colonne><colonne>Fin</colonne><colonne>Bloc</colonne><colonne>Id</colonne><colonne>Systeme</colonne></entete>"
$(which fdisk) -l | grep '^/dev/' | sed 's/*//g' | awk '{print "<ligne><colonne>" $1 "</colonne><colonne>" $2 "</colonne><colonne>" $3 "</colonne><colonne>" $4 "</colonne><colonne>" $5 "</colonne><colonne>" $6 "</colonne></ligne>"}'
echo "</tableau>"

else
echo "<paragraph>Programme <i>fdisk</i> introuvable !</paragraph>"
fi
echo "</section>"
}

taille_partitions(){
echo "<section id=\"V\" noNumber=\"1\"><title>Taille des partitions</title>
<tableau width=\"80%\" border=\"1\">
<entete><colonne>Systeme de fichier</colonne><colonne>Taille totale</colonne><colonne>Taille occupee</colonne><colonne>Taille disponible</colonne><colonne>Pourcentage occupe</colonne><colonne>Point de montage</colonne></entete>"

df -h | sed '/\.dev/d' | awk '/^\// {print "<ligne><colonne>" $1 "</colonne><colonne>" $2 "</colonne><colonne>" $3 "</colonne><colonne>" $4 "</colonne><colonne>" $5 "</colonne><colonne>" $6 "</colonne></ligne>"}'

echo "</tableau>"
echo "</section>"
}

bootmanager(){
echo "<section id=\"VI\" noNumber=\"1\"><title>Gestionnaire de demarrage</title>"
echo -e "<code langage=\"other\"><![CDATA["
if [ -f "/etc/lilo.conf" ];then
cat /etc/lilo.conf | sed 's/#.*$//g; /^[[:space:]]*$/d'
fi

if [ -f "/boot/grub/menu.lst" ];then
cat /boot/grub/menu.lst | sed 's/#.*$//g; /^[[:space:]]*$/d'
fi
echo -e "]]></code>"
echo "</section>"
}

memoire(){
echo "<section id=\"VII\" noNumber=\"1\"><title>Memoire</title>
<tableau width=\"80%\" border=\"1\">
<entete><colonne>Type de memoire</colonne><colonne>Taille</colonne></entete>"

cat /proc/meminfo | awk '/^MemTotal/ {print "<ligne><colonne>Memoire vive</colonne><colonne>" $2 " " $3 "</colonne></ligne>"}' | tr -d "\n"
cat /proc/meminfo | awk '/^SwapTotal/ {print "<ligne><colonne>Swap</colonne><colonne>" $2 " " $3 "</colonne></ligne>"}' | tr -d "\n"

echo "</tableau>"
echo "</section>"
}

pci(){
echo "<section id=\"VIII\" noNumber=\"1\"><title>PCI</title>
<code langage=\"other\"><![CDATA["

if [ -f /bin/lspci ]
then
	/bin/lspci
else
	cat /proc/pci
fi

echo "]]></code>"
echo "</section>"
}

info_X(){
echo "<section id=\"IX\" noNumber=\"1\"><title>Version de X window</title>
<code langage=\"other\"><![CDATA["

X -version 2>&1

echo "]]></code>"
echo "</section>"
}

conf_X(){
echo "<section id=\"X\" noNumber=\"1\"><title>Fichier de configuration de X window</title>
<code langage=\"other\"><![CDATA["

if [ -f '/etc/X11/XF86Config-4' ]
then
	cat '/etc/X11/XF86Config-4' | sed 's/#.*$//g; /^[[:space:]]*$/d'
elif [ -f '/etc/X11/XF86Config' ]
then
	cat '/etc/X11/XF86Config' | sed 's/#.*$//g; /^[[:space:]]*$/d'
else
	cat '/etc/X11/xorg.conf' | sed 's/#.*$//g; /^[[:space:]]*$/d'
fi
echo "]]></code>"
echo "</section>"
}

version_programmes_cles(){
echo "<section id=\"XI\" noNumber=\"1\"><title>Versions de quelques programmes cles</title>"
if [ -f $(which gcc) ]
then
echo "<section id=\"XI-A\" noNumber=\"1\"><title>GNU C</title><code langage=\"other\"><![CDATA[$(gcc --version)]]></code></section>"
fi

if [ -f $(which mono) ]
then
echo "<section id=\"XI-B\" noNumber=\"1\"><title>GNU C</title><code langage=\"other\"><![CDATA[$(mono -V)]]></code></section>"
fi

if [ -f $(which make) ]
then
echo "<section id=\"XI-C\" noNumber=\"1\"><title>GNU make</title><code langage=\"other\"><![CDATA[$(make -v)]]></code></section>"
fi

if [ -f $(which ld) ]
then
echo "<section id=\"XI-D\" noNumber=\"1\"><title>Binutils</title><code langage=\"other\"><![CDATA[$(ld -v)]]></code></section>"
fi

if [ -f $(which fdformat) ]
then
echo "<section id=\"XI-E\" noNumber=\"1\"><title>Util-linux</title><code langage=\"other\"><![CDATA[$(fdformat --version)]]></code></section>"
fi

if [ -f $(which insmod) ]
then
echo "<section id=\"XI-F\" noNumber=\"1\"><title>Modutils</title><code langage=\"other\"><![CDATA[$(insmod -V 2>&1)]]></code></section>"
fi

if [ -f $(which tune2fs) ]
then
echo "<section id=\"XI-G\" noNumber=\"1\"><title>E2fsprogs</title><code langage=\"other\"><![CDATA[$(tune2fs)]]></code></section>"
fi

if [ -f $(which patch) ]
then
echo "<section id=\"XI-H\" noNumber=\"1\"><title>Patch</title><code langage=\"other\"><![CDATA[$(patch -v)]]></code></section>"
fi

echo "</section>"
}

langages_interpretes(){
echo "<section id=\"XII\" noNumber=\"1\"><title>Languages de programmation interprete</title>"
if [ -f $(which perl) ]
then
echo '<section id="XII-A" noNumber="1"><title>Perl</title><code langage="other"><![CDATA['
perl -v
echo ']]></code></section>'
fi

if [ -f $(which java) ]
then
echo '<section id="XII-B" noNumber="1"><title>Java</title><code langage="other"><![CDATA['
java -version
echo ']]></code></section>'
fi

if [ -f $(which python) ]
then
echo '<section id="XII-C" noNumber="1"><title>Python</title><code langage="other"><![CDATA['
python -V 2>&1
echo ']]></code></section>'
fi

if [ -f $(which ruby) ]
then
echo '<section id="XII-D" noNumber="1"><title>Ruby</title><code langage="other"><![CDATA['
ruby --version
echo ']]></code></section>'
fi

echo "</section>"
}

environnement(){
echo "<section id=\"XIII\" noNumber=\"1\"><title>Variables d'environnement</title>"
echo '<code langage="other"><![CDATA['
env;
echo ']]></code></section>'
}

modules_charges(){
echo "<section id=\"XIV\" noNumber=\"1\"><title>Modules charges</title>
<tableau width=\"80%\" border=\"1\">
	<entete>
		<colonne>Module</colonne>
		<colonne>Taille</colonne>
	</entete>"
/sbin/lsmod | grep [0-9] | awk '{print "<ligne><colonne>" $1 "</colonne><colonne>" $2 "</colonne></ligne>"}'
echo "</tableau>"
echo "</section>"
}

modules_disponibles(){
echo "<section id=\"XV\" noNumber=\"1\"><title>Modules disponibles</title>
<tableau width=\"80%\" border=\"1\">
<entete><colonne>Module</colonne><colonne>Description</colonne></entete>"
if [ $KERNEL == '6' ];then
for i in $(find /lib/modules/$(uname -r)/ -name *.ko -exec basename \{\} .ko \; | sort)
do
echo "<ligne><colonne>$i</colonne><colonne>$(modinfo -d $i|sed 's/&/&amp;/g')</colonne></ligne>"
done
else
for i in $(find /lib/modules/$(uname -r)/ -name *.o -exec basename \{\} .o \; | sort)
do
echo "<ligne><colonne>$i</colonne><colonne>$(modinfo -d $i|sed 's/&/&amp;/g ; s/^\"\(.*\)\"$/\1/')</colonne></ligne>"
done
fi
echo "</tableau>"
echo "</section>"
}

faitDocument()
{
echo "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>
<document>
	<xiti>
		<!-- compteur -->
		<logger>logv28</logger>
		<id>205564</id>
		<nom>configuration</nom>
	</xiti>
	<!-- en-tete d'article -->
	<entete>
		<rubrique>3</rubrique>
		<meta>
			<description>$MACHINE de $PERSONNE</description>
			<keywords>langage, C, tutoriel, tutorial, cour, programmation, informatique</keywords>
		</meta>
		<titre>
			<page>$MACHINE de $PERSONNE</page>
			<article>$MACHINE de $PERSONNE</article>
		</titre>
		<date>11 Janvier 2006</date>
		<miseajour>$DATEFICHIER</miseajour>
		<css>./article.css</css>
		<licauteur>Nicolas Joseph</licauteur>
		<lictype>2</lictype>
		<licannee>2006</licannee>
		<serveur>nicolasj-http</serveur>
		<chemin>configuration/</chemin>
		<urlhttp>http://nicolasj.developpez.com/configuration/</urlhttp>
		<serveurftp>nicolasj-ftp</serveurftp>
		<cheminftp></cheminftp>
		<urlftp>ftp://ftp-developpez.com/nicolasj/</urlftp>
    <nopdf/>
	</entete>
	<!-- description des auteurs -->
	<authorDescriptions>
		<authorDescription name=\"gege2061\">
			<fullname>Nicolas Joseph</fullname>
			<url>http://www.developpez.net/forums/profile.php?mode=viewprofile&amp;u=47082</url>
			<homepage>
				<title>home</title>
				<url>http://nicolasj.developpez.com</url>
			</homepage>
		</authorDescription>
	</authorDescriptions>
	<!-- licence de reproduction affiche en bas de l'article -->
	<licence>
		Ce document est issu de http://www.developpez.com et reste la propriete exclusive de son auteur.
		La copie, modification et/ou distribution par quelque moyen que ce soit est soumise à l'obtention prealable de l'autorisation de l'auteur.
	</licence>
	<!-- url où trouver le fichier inclus pour creer le cadre des renvois en fin d'article -->
	<reference></reference>
	<!-- article proprement dit -->
	<summary>"

processeur;
systeme_exploitation;
fs_configures;
fs_presents;
taille_partitions;
bootmanager;
memoire;
pci;
info_X;
conf_X;
version_programmes_cles;
langages_interpretes;
environnement;
modules_charges;
modules_disponibles;
echo "	</summary>
</document>"
}

faitDocument 2> /dev/null

exit 0
